@@ -26,7 +26,7 @@ class NoResultError(Error):
 __all__ += ['NoResultError']
 
 
-class InvalidParamError(Error, TypeError):
+class InvalidParamError(Error, ValueError):
     """
     Invalid parameter passed.
     """
