@@ -820,14 +820,14 @@ def csv_split(
             e = (0,) if cols is None or _csv_utils.cols_are_type(cols, int) else (yield) 
             (cols_, single, inds, uniques, copies, max_ind, types_, c_types, cast_back) = \
                 _csv_utils._csv_attribs((e, ), cols, types__, delimit, comment, skip_init_space)
-            r = dagpype_c.col_reader(
+            r = dagpype_c.ColReader(
                 [], 
                 delimit, comment, 1 if skip_init_space else 0, 
                 1 if single else 0,
                 inds, uniques, copies, max_ind,
                 c_types)
             while True:
-                e = dagpype_c.col_reader_parse_string(r, (yield))
+                e = r.parse_string((yield))
                 if not cast_back:
                     target.send(e)
                 elif single:
@@ -1308,10 +1308,10 @@ def enumerate_(start = 0):
    
     @filters
     def _dagpype_internal_fn_act(target):
-        e = dagpype_c.enumerator(start)
+        e = dagpype_c.Enumerator(start)
         try:
             while True:
-                target.send(dagpype_c.enumerator_next(e, (yield)))
+                target.send(e.next((yield)))
         except GeneratorExit:           
             target.close()               
 
