@@ -95,7 +95,7 @@ def stream_vals(stream,
     Examples:
 
     >>> # Find the correlation between two named columns.
-    >>> csv_vals('meteo.csv', ('wind', 'rain')) | corr()
+    >>> csv_vals('meteo.csv', (b'wind', b'rain')) | corr()
     0.74
     >>> # Find the correlation between two indexed columns.
     >>> csv_vals('data.csv', (0, 3)) | corr()
