@@ -14,7 +14,7 @@ struct ColReader
 {
     PyObject_HEAD
 
-    PyObject *input_iter;
+    PyObject * input_iter;
 
     char delimit;
     char comment;
@@ -58,7 +58,7 @@ col_reader_dealloc(ColReader * self)
 }
 
 extern "C" PyObject *
-col_reader(PyObject *module, PyObject *args, PyObject *keyword_args)
+col_reader_new(PyTypeObject * type, PyObject *args, PyObject *keyword_args)
 {
     ColReader * const self = PyObject_GC_New(ColReader, &ColReaderType);
     if (self == NULL) {
@@ -195,15 +195,13 @@ col_reader_iternext(ColReader * self)
 }
 
 extern "C" PyObject *
-col_reader_parse_string(PyObject *module, PyObject *args, PyObject *keyword_args)
+col_reader_parse_string(ColReader * self, PyObject *args, PyObject *keyword_args)
 {
-    ColReader * self;
     PyObject * lineobj;
     if (!PyArg_ParseTuple(
             args, 
-            "OO",
-            reinterpret_cast<PyObject **>(&self),
-            reinterpret_cast<PyObject **>(&lineobj)) || self == NULL || lineobj == NULL) {
+            "O",
+            reinterpret_cast<PyObject **>(&lineobj)) || lineobj == NULL) {
         PyErr_SetString(PyExc_TypeError, "Failed to parse stuff");
         return NULL;
     }
@@ -244,6 +242,7 @@ col_reader_clear(ColReader * self)
 }
 
 static PyMethodDef col_reader_methods[] = {
+    { "parse_string", (PyCFunction)col_reader_parse_string, METH_VARARGS, "" },
     { NULL, NULL }
 };
 
@@ -255,16 +254,16 @@ PyDoc_STRVAR(ColReaderType_doc, "");
 
 PyTypeObject ColReaderType = {
     PyVarObject_HEAD_INIT(NULL, 0)
-    "dagpype_c.col_reader",               /*tp_name*/
+    "dagpype_c.ColReader",               /*tp_name*/
     sizeof(ColReader),                   /*tp_basicsize*/
     0,                                      /*tp_itemsize*/
     /* methods */
     (destructor)col_reader_dealloc,          /*tp_dealloc*/
-    0,                           /*tp_print*/
-    0,                         /*tp_getattr*/
-    0,                         /*tp_setattr*/
-    0,                             /*tp_compare*/
-    0,                            /*tp_repr*/
+    0,                                         /*tp_print*/
+    0,                                         /*tp_getattr*/
+    0,                                         /*tp_setattr*/
+    0,                                          /*tp_compare*/
+    0,                                        /*tp_repr*/
     0,                                      /*tp_as_number*/
     0,                                      /*tp_as_sequence*/
     0,                                      /*tp_as_mapping*/
@@ -285,6 +284,13 @@ PyTypeObject ColReaderType = {
     (getiterfunc)col_reader_iternext,        /*tp_iternext*/
     col_reader_methods,                      /*tp_methods*/
     col_reader_memberlist,                   /*tp_members*/
-    0,                                      /*tp_getset*/
+    0,                       /* tp_getset */
+    0,                       /* tp_base */
+    0,                       /* tp_dict */
+    0,                       /* tp_descr_get */
+    0,                       /* tp_descr_set */
+    0,                       /* tp_dictoffset */
+    0,      /* tp_init */
+    0,                         /* tp_alloc */
+    col_reader_new,                 /* tp_new */
 };
-
