@@ -18,6 +18,10 @@
 #define DAGPYPE_NO_USE_AIO
 #endif // #if defined(_WIN32) || defined (_WIN64)
 
+#if defined(__APPLE__)
+#define DAGPYPE_NO_USE_AIO
+#endif // #if defined(__APPLE__)
+
 #if defined(__GNUC__) && !defined(DAGPYPE_NO_USE_AIO)
 #define DAGPYPE_USE_AIO
 #endif // #if defined(__GNUC__) && !defined(DAGPYPE_NO_USE_AIO)
